@@ -11,5 +11,5 @@ __PACKAGE__->set_primary_key('trackid');
 __PACKAGE__->belongs_to('cd' => 't::app::Main::Result::Cd', 'cdid');
 
 __PACKAGE__->load_components(qw/ Result::ColumnData /);
-__PACKAGE__->register_relationships_columns_data();
+__PACKAGE__->register_relationships_column_data();
 1;
